@@ -9,7 +9,7 @@
 #
 ###############################################################################
 #
-#   $Id: Client.pm,v 1.10 2002/08/31 06:42:26 rjray Exp $
+#   $Id: Client.pm,v 1.12 2002/12/30 07:30:42 rjray Exp $
 #
 #   Description:    This class implements an RPC::XML client, using LWP to
 #                   manage the underlying communication protocols. It relies
@@ -46,9 +46,7 @@ require URI;
 use RPC::XML 'bytelength';
 require RPC::XML::Parser;
 
-$VERSION = do { my @r=(q$Revision: 1.10 $=~/\d+/g); sprintf "%d."."%02d"x$#r,@r };
-
-1;
+$VERSION = do { my @r=(q$Revision: 1.12 $=~/\d+/g); sprintf "%d."."%02d"x$#r,@r };
 
 ###############################################################################
 #
@@ -204,7 +202,8 @@ sub send_request
 
     $reqclone = $self->{__request}->clone;
     $content = $req->as_string;
-    if ($self->compress_requests and ($compress = $self->compress) and
+    $compress = $self->compress; # Avoid making 4+ calls to the method
+    if ($self->compress_requests and $compress and
         length($content) > $self->compress_thresh)
     {
         $content = Compress::Zlib::compress($content);
@@ -231,7 +230,7 @@ sub send_request
     }
     else
     {
-        if ($response->content_encoding =~ /deflate/)
+        if (($response->content_encoding || '') =~ /deflate/)
         {
             $message =  "$me: Compressed content encoding not supported";
             return (ref($self->{__error_cb}) eq 'CODE') ?
@@ -275,7 +274,8 @@ sub send_request
 ###############################################################################
 sub uri
 {
-    $_[0]->{__request}->uri($_[1]);
+    my $self = shift;
+    $self->{__request}->uri(@_);
 }
 
 ###############################################################################
@@ -366,6 +366,8 @@ sub combined_handler
     ($self->fault_handler($newval), $self->error_handler($newval));
 }
 
+1;
+
 __END__
 
 =pod
